@@ -93,6 +93,7 @@ ALL_ROUTES = [
     ('block:access-list', 'SoftLayer.CLI.block.access.list:cli'),
     ('block:access-revoke', 'SoftLayer.CLI.block.access.revoke:cli'),
     ('block:access-password', 'SoftLayer.CLI.block.access.password:cli'),
+    ('block:duplicate-convert-status', 'SoftLayer.CLI.block.duplicate_convert_status:cli'),
     ('block:subnets-list', 'SoftLayer.CLI.block.subnets.list:cli'),
     ('block:subnets-assign', 'SoftLayer.CLI.block.subnets.assign:cli'),
     ('block:subnets-remove', 'SoftLayer.CLI.block.subnets.remove:cli'),
@@ -124,7 +125,11 @@ ALL_ROUTES = [
     ('block:volume-limits', 'SoftLayer.CLI.block.limit:cli'),
     ('block:volume-refresh', 'SoftLayer.CLI.block.refresh:cli'),
     ('block:volume-convert', 'SoftLayer.CLI.block.convert:cli'),
+    ('block:volume-options', 'SoftLayer.CLI.block.options:cli'),
     ('block:volume-set-note', 'SoftLayer.CLI.block.set_note:cli'),
+    ('block:object-list', 'SoftLayer.CLI.block.object_list:cli'),
+    ('block:object-storage-detail', 'SoftLayer.CLI.block.object_storage_detail:cli'),
+    ('block:object-storage-permission', 'SoftLayer.CLI.block.object_storage_permission:cli'),
 
     ('email', 'SoftLayer.CLI.email'),
     ('email:list', 'SoftLayer.CLI.email.list:cli'),
@@ -142,6 +147,7 @@ ALL_ROUTES = [
     ('file:access-authorize', 'SoftLayer.CLI.file.access.authorize:cli'),
     ('file:access-list', 'SoftLayer.CLI.file.access.list:cli'),
     ('file:access-revoke', 'SoftLayer.CLI.file.access.revoke:cli'),
+    ('file:duplicate-convert-status', 'SoftLayer.CLI.file.duplicate_convert_status:cli'),
     ('file:replica-failback', 'SoftLayer.CLI.file.replication.failback:cli'),
     ('file:replica-failover', 'SoftLayer.CLI.file.replication.failover:cli'),
     ('file:disaster-recovery-failover', 'SoftLayer.CLI.file.replication.disaster_recovery_failover:cli'),
@@ -169,6 +175,7 @@ ALL_ROUTES = [
     ('file:volume-limits', 'SoftLayer.CLI.file.limit:cli'),
     ('file:volume-refresh', 'SoftLayer.CLI.file.refresh:cli'),
     ('file:volume-convert', 'SoftLayer.CLI.file.convert:cli'),
+    ('file:volume-options', 'SoftLayer.CLI.file.options:cli'),
     ('file:volume-set-note', 'SoftLayer.CLI.file.set_note:cli'),
 
     ('firewall', 'SoftLayer.CLI.firewall'),
@@ -177,6 +184,7 @@ ALL_ROUTES = [
     ('firewall:detail', 'SoftLayer.CLI.firewall.detail:cli'),
     ('firewall:edit', 'SoftLayer.CLI.firewall.edit:cli'),
     ('firewall:list', 'SoftLayer.CLI.firewall.list:cli'),
+    ('firewall:monitoring', 'SoftLayer.CLI.firewall.monitoring:cli'),
 
     ('globalip', 'SoftLayer.CLI.globalip'),
     ('globalip:assign', 'SoftLayer.CLI.globalip.assign:cli'),
@@ -204,6 +212,7 @@ ALL_ROUTES = [
     ('ipsec:translation-remove', 'SoftLayer.CLI.vpn.ipsec.translation.remove:cli'),
     ('ipsec:translation-update', 'SoftLayer.CLI.vpn.ipsec.translation.update:cli'),
     ('ipsec:update', 'SoftLayer.CLI.vpn.ipsec.update:cli'),
+    ('ipsec:order', 'SoftLayer.CLI.vpn.ipsec.order:cli'),
 
     ('loadbal', 'SoftLayer.CLI.loadbal'),
     ('loadbal:detail', 'SoftLayer.CLI.loadbal.detail:cli'),
@@ -323,6 +332,7 @@ ALL_ROUTES = [
     ('subnet:list', 'SoftLayer.CLI.subnet.list:cli'),
     ('subnet:lookup', 'SoftLayer.CLI.subnet.lookup:cli'),
     ('subnet:edit-ip', 'SoftLayer.CLI.subnet.edit_ip:cli'),
+    ('subnet:route', 'SoftLayer.CLI.subnet.route:cli'),
 
     ('tags', 'SoftLayer.CLI.tags'),
     ('tags:cleanup', 'SoftLayer.CLI.tags.cleanup:cli'),
@@ -353,8 +363,10 @@ ALL_ROUTES = [
     ('user:edit-details', 'SoftLayer.CLI.user.edit_details:cli'),
     ('user:create', 'SoftLayer.CLI.user.create:cli'),
     ('user:delete', 'SoftLayer.CLI.user.delete:cli'),
+    ('user:device-access', 'SoftLayer.CLI.user.device_access:cli'),
     ('user:vpn-manual', 'SoftLayer.CLI.user.vpn_manual:cli'),
     ('user:vpn-subnet', 'SoftLayer.CLI.user.vpn_subnet:cli'),
+    ('user:remove-access', 'SoftLayer.CLI.user.remove_access:cli'),
 
     ('vlan', 'SoftLayer.CLI.vlan'),
     ('vlan:create', 'SoftLayer.CLI.vlan.create:cli'),
@@ -372,11 +384,13 @@ ALL_ROUTES = [
 
     ('autoscale', 'SoftLayer.CLI.autoscale'),
     ('autoscale:list', 'SoftLayer.CLI.autoscale.list:cli'),
+    ('autoscale:create', 'SoftLayer.CLI.autoscale.create:cli'),
     ('autoscale:detail', 'SoftLayer.CLI.autoscale.detail:cli'),
     ('autoscale:scale', 'SoftLayer.CLI.autoscale.scale:cli'),
     ('autoscale:logs', 'SoftLayer.CLI.autoscale.logs:cli'),
     ('autoscale:tag', 'SoftLayer.CLI.autoscale.tag:cli'),
-    ('autoscale:edit', 'SoftLayer.CLI.autoscale.edit:cli')
+    ('autoscale:edit', 'SoftLayer.CLI.autoscale.edit:cli'),
+    ('autoscale:delete', 'SoftLayer.CLI.autoscale.delete:cli'),
 ]
 
 ALL_ALIASES = {
