@@ -345,19 +345,19 @@ class VirtTests(testing.TestCase):
                                            'getResourceRecords')
         getResourceRecords.return_value = []
         createAargs = ({
-                           'type': 'a',
-                           'host': 'vs-test1',
-                           'domainId': 12345,  # from SoftLayer_Account::getDomains
-                           'data': '172.16.240.2',
-                           'ttl': 7200
-                       },)
+            'type': 'a',
+            'host': 'vs-test1',
+            'domainId': 12345,  # from SoftLayer_Account::getDomains
+            'data': '172.16.240.2',
+            'ttl': 7200
+        },)
         createPTRargs = ({
-                             'type': 'ptr',
-                             'host': '2',
-                             'domainId': 123456,
-                             'data': 'vs-test1.test.sftlyr.ws',
-                             'ttl': 7200
-                         },)
+            'type': 'ptr',
+            'host': '2',
+            'domainId': 123456,
+            'data': 'vs-test1.test.sftlyr.ws',
+            'ttl': 7200
+        },)
 
         result = self.run_command(['vs', 'dns-sync', '100'])
 
@@ -400,12 +400,12 @@ class VirtTests(testing.TestCase):
             }
         }
         createV6args = ({
-                            'type': 'aaaa',
-                            'host': 'vs-test1',
-                            'domainId': 12345,
-                            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
-                            'ttl': 7200
-                        },)
+            'type': 'aaaa',
+            'host': 'vs-test1',
+            'domainId': 12345,
+            'data': '2607:f0d0:1b01:0023:0000:0000:0000:0004',
+            'ttl': 7200
+        },)
         guest.return_value = test_guest
         result = self.run_command(['vs', 'dns-sync', '--aaaa-record', '100'])
         self.assert_no_fail(result)
@@ -609,7 +609,13 @@ class VirtTests(testing.TestCase):
                                    '100'])
 
         self.assert_no_fail(result)
-        self.assertEqual(result.output, '')
+        expected_output = '"The userdata of virtual server instance: 100 was updated."\n' \
+                          + '"The hostname of virtual server instance: 100 was updated."\n' \
+                          + '"The domain of virtual server instance: 100 was updated."\n' \
+                          + '"The tags of virtual server instance: 100 was updated."\n' \
+                          + '"The public speed of virtual server instance: 100 was updated."\n' \
+                          + '"The private speed of virtual server instance: 100 was updated."\n'
+        self.assertEqual(result.output, expected_output)
 
         self.assert_called_with(
             'SoftLayer_Virtual_Guest', 'editObject',
@@ -941,3 +947,13 @@ class VirtTests(testing.TestCase):
     def test_monitoring_vs(self):
         result = self.run_command(['vs', 'monitoring', '1234'])
         self.assert_no_fail(result)
+
+    def test_last_transaction_empty(self):
+        vg_return = SoftLayer_Virtual_Guest.getObject
+        transaction = []
+
+        vg_return['lastTransaction'] = transaction
+        mock = self.set_mock('SoftLayer_Virtual_Guest', 'getObject')
+        mock.return_value = vg_return
+        result = self.run_command(['vs', 'detail', '100'])
+        self.assert_no_fail(result)
