@@ -948,6 +948,10 @@ class HardwareTests(testing.TestCase):
         self.assertEqual(result[0]['hardwareComponentModel']['name'], 'IMM2 - Onboard')
         self.assertEqual(result[0]['hardwareComponentModel']['firmwares'][0]['version'], '5.60')
 
+    def test_sensor(self):
+        self.hardware.get_sensors(100)
+        self.assert_called_with('SoftLayer_Hardware', 'getSensorData')
+
 
 class HardwareHelperTests(testing.TestCase):
 
